@@ -12,15 +12,15 @@ Options:
 """
 
 import os
+import logging
 from concurrent.futures import ProcessPoolExecutor, as_completed
 from pathlib import Path
-from typing import List, Union
+from typing import List, Union, Iterator
 
 from docopt import docopt
-from rich import print
 
 from .elf import ELFChecksecData, ELFSecurity, is_elf
-from .errors import ErrorNotAnElf, ErrorParsingFailed
+from .errors import ErrorParsingFailed
 from .output import JSONOutput, RichOutput
 from .pe import PEChecksecData, PESecurity, is_pe
 
@@ -37,7 +37,15 @@ def walk_filepath_list(filepath_list: List[Path], recursive: bool = False):
             yield path
 
 
+def walk_lief_parsable_list(filepath_list: List[Path], recusive: bool = False) -> Iterator[Path]:
+    for path in walk_filepath_list(filepath_list, recusive):
+        if is_elf(path) or is_pe(path):
+            yield path
+
+
 def checksec_file(filepath: Path) -> Union["ELFChecksecData", "PEChecksecData"]:
+    """Check the security of a given file. Workers main execution"""
+    logging.debug("Worker %s: checking %s", os.getpid(), filepath)
     if not filepath.exists():
         raise FileNotFoundError()
     if is_elf(filepath):
@@ -56,6 +64,12 @@ def main(args):
     json = args["--json"]
     recursive = args["--recursive"]
 
+    # logging
+    formatter = "%(asctime)s %(levelname)s:%(name)s:%(message)s"
+    log_lvl = logging.INFO
+    if debug:
+        log_lvl = logging.DEBUG
+    logging.basicConfig(level=log_lvl, format=formatter)
     # default output: Rich console
     output_cls = RichOutput
     if json:
@@ -65,30 +79,24 @@ def main(args):
         # we need to consume the iterator once to get the total
         # for the progress bar
         check_output.enumerating_tasks_start()
-        count = sum(1 for i in walk_filepath_list(filepath_list, recursive))
+        count = sum(1 for i in walk_lief_parsable_list(filepath_list, recursive))
         check_output.enumerating_tasks_stop(count)
         with ProcessPoolExecutor(max_workers=workers) as pool:
             check_output.processing_tasks_start()
             future_to_checksec = {
                 pool.submit(checksec_file, filepath): filepath
-                for filepath in walk_filepath_list(filepath_list, recursive)
+                for filepath in walk_lief_parsable_list(filepath_list, recursive)
             }
             for future in as_completed(future_to_checksec):
                 filepath = future_to_checksec[future]
                 try:
                     data = future.result()
                 except FileNotFoundError:
-                    if debug:
-                        print(f"{filepath} does not exist")
-                except ErrorNotAnElf:
-                    if debug:
-                        print(f"{filepath} is not a valid ELF")
+                    logging.debug("%s does not exist", filepath)
                 except ErrorParsingFailed:
-                    if debug:
-                        print(f"{filepath} ELF parsing failed")
+                    logging.debug("%s LIEF parsing failed")
                 except NotImplementedError:
-                    if debug:
-                        print(f"{filepath} executable format is not supported. (Only ELF or PE)")
+                    logging.debug("%s: Not an ELF/PE. Skipping", filepath)
                 else:
                     check_output.add_checksec_result(filepath, data)
                 finally:
